FO tree node data structures
Structs
- FoNode
- A node in the FO tree
Enums
- Blank
OrNot Blank - Blank or not blank page for conditional page master selection
- FoNode
Data - FO node data - the actual formatting object information
- OddOr
Even - Odd or even page for conditional page master selection
- Page
Position - Page position for conditional page master selection
- Retrieve
Position - Position for retrieving markers from the page